Host library for controlling a WiConnect enabled Wi-Fi module.

Dependents:   wiconnect-ota_example wiconnect-web_setup_example wiconnect-test-console wiconnect-tcp_server_example ... more

Revision:
17:7268f365676b
Parent:
16:7f1d6d359787
Child:
21:17bb3eddcbae
--- a/FileInterface.h	Wed Aug 13 04:41:04 2014 -0700
+++ b/FileInterface.h	Sat Aug 23 05:39:17 2014 -0700
@@ -97,13 +97,13 @@
      *
      * @brief Open a file on the Wiconnect WiFi module filesystem for reading.
      *
      * Once opened, the returned @ref File object may only be read.
      *
      * @param[out] file The @ref File object to read data from
      * @param[in] name The name of the file to open
      * @return Result of method. See @ref WiconnectResult
      */
-    WiconnectResult openFile(File &file, const char *name);
+    WiconnectResult openFile(WiconnectFile &file, const char *name);
 
     /**
      * @ingroup api_file_methods
@@ -120,10 +120,10 @@
      *
      * @brief Delete a file for the Wiconnect WiFi module filesystem.
      *
      * @param[in] file The @ref File object of the file to delete
      * @return Result of method. See @ref WiconnectResult
      */
-    WiconnectResult deleteFile(const File &file);
+    WiconnectResult deleteFile(const WiconnectFile &file);
 
     /**
      * @ingroup api_file_methods
@@ -97,13 +97,13 @@
      * @brief Open a file on the Wiconnect WiFi module filesystem for reading.
      *
-     * Once opened, the returned @ref File object may only be read.
+     * Once opened, the returned @ref WiconnectFile object may only be read.
      *
@@ -97,13 +97,13 @@
      *
-     * @param[out] file The @ref File object to read data from
+     * @param[out] file The @ref WiconnectFile object to read data from
      * @param[in] name The name of the file to open
      * @return Result of method. See @ref WiconnectResult
@@ -120,10 +120,10 @@
      * @brief Delete a file for the Wiconnect WiFi module filesystem.
      *
-     * @param[in] file The @ref File object of the file to delete
+     * @param[in] file The @ref WiconnectFile object of the file to delete
      * @return Result of method. See @ref WiconnectResult
      */